cmd

package
v2.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package cmd handle the cli commands

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute(ctx *context.Context, rootCmd *cobra.Command) error

func NewRootCmd

func NewRootCmd(ctx *context.Context) *cobra.Command

func RegisterSubCommands

func RegisterSubCommands(ctx *context.Context, rootCmd *cobra.Command)

Types

This section is empty.

Directories

Path Synopsis
errors
Package errors provides the central CLI error handler that emits a structured JSON/YAML envelope to stderr when --output=json|yaml, and falls back to the existing plain-text logger for text/TUI mode.
Package errors provides the central CLI error handler that emits a structured JSON/YAML envelope to stderr when --output=json|yaml, and falls back to the existing plain-text logger for text/TUI mode.
response
Package response provides a structured success-response helper that is symmetric with the error envelope in cmd/internal/errors.
Package response provides a structured success-response helper that is symmetric with the error envelope in cmd/internal/errors.

Jump to