Documentation
¶
Index ¶
- func MarkFlagFilename(_ *context.Context, cmd *cobra.Command, name string)
- func MarkFlagMutuallyExclusive(cmd *cobra.Command, names ...string)
- func MarkFlagRequired(_ *context.Context, cmd *cobra.Command, name string)
- func MarkOneFlagRequired(cmd *cobra.Command, names ...string)
- func RegisterBrowseCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterCacheCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterCliCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterConfigCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterExecCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterFlag(ctx *context.Context, cmd *cobra.Command, flag flags.Metadata)
- func RegisterLogsCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterMCPCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterPersistentFlag(_ *context.Context, cmd *cobra.Command, flag flags.Metadata)
- func RegisterSchemaCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterSecretCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterSyncCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterTemplateCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterVaultCmd(ctx *context.Context, rootCmd *cobra.Command)
- func RegisterWorkspaceCmd(ctx *context.Context, rootCmd *cobra.Command)
- func SetView(ctx *context.Context, cmd *cobra.Command, view tuikit.View)
- func StartTUI(ctx *context.Context, cmd *cobra.Command)
- func TUIEnabled(ctx *context.Context, cmd *cobra.Command) bool
- func WaitForTUI(ctx *context.Context, cmd *cobra.Command)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MarkOneFlagRequired ¶
func RegisterFlag ¶
func RegisterPersistentFlag ¶
Types ¶
This section is empty.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package errors provides the central CLI error handler that emits a structured JSON/YAML envelope to stderr when --output=json|yaml, and falls back to the existing plain-text logger for text/TUI mode.
|
Package errors provides the central CLI error handler that emits a structured JSON/YAML envelope to stderr when --output=json|yaml, and falls back to the existing plain-text logger for text/TUI mode. |
|
Package response provides a structured success-response helper that is symmetric with the error envelope in cmd/internal/errors.
|
Package response provides a structured success-response helper that is symmetric with the error envelope in cmd/internal/errors. |
Click to show internal directories.
Click to hide internal directories.