templates

package
v2.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2026 License: Apache-2.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TemplateResult

type TemplateResult struct {
	FlowfileName string            `json:"flowfileName"         yaml:"flowfileName"`
	FlowfilePath string            `json:"flowfilePath"         yaml:"flowfilePath"`
	OutputDir    string            `json:"outputDir"            yaml:"outputDir"`
	FormValues   map[string]string `json:"formValues,omitempty" yaml:"formValues,omitempty"`
	Artifacts    []string          `json:"artifacts,omitempty"  yaml:"artifacts,omitempty"`
}

TemplateResult contains structured metadata about a successful template generation, suitable for returning to callers that need machine-readable output.

func ProcessTemplate

func ProcessTemplate(
	ctx *context.Context,
	template *executable.Template,
	ws *workspace.Workspace,
	flowfileName, flowfileDir string,
	preseeded map[string]string,
) (*TemplateResult, error)

Jump to