Documentation
¶
Index ¶
- Constants
- func ApplyExecConfig(exec *executable.Executable, result *ParseResult) error
- func ExecutablesFromBatFile(wsPath, filePath string) (*executable.Executable, error)
- func ExecutablesFromDockerCompose(wsPath, path string) (executable.ExecutableList, error)
- func ExecutablesFromImports(wsName string, flowFile *executable.FlowFile) (executable.ExecutableList, error)
- func ExecutablesFromMakefile(wsPath, path string) (executable.ExecutableList, error)
- func ExecutablesFromPackageJSON(wsPath, path string) (executable.ExecutableList, error)
- func ExecutablesFromPs1File(wsPath, filePath string) (*executable.Executable, error)
- func ExecutablesFromShFile(wsPath, filePath string) (*executable.Executable, error)
- func InferVerb(name string) executable.Verb
- func NormalizeName(name, verb string) string
- type ParseResult
Constants ¶
const ( TimeoutConfigurationKey = "timeout" VerbConfigurationKey = "verb" NameConfigurationKey = "name" AliasConfigurationKey = "alias" DescriptionConfigurationKey = "description" VisibilityConfigurationKey = "visibility" TagConfigurationKey = "tag" ParamConfigurationKey = "param" ArgConfigurationKey = "arg" DirConfigurationKey = "dir" LogModeConfigurationKey = "logmode" InternalListSeparator = "|" InternalValueSeparator = ":" )
Variables ¶
This section is empty.
Functions ¶
func ApplyExecConfig ¶
func ApplyExecConfig(exec *executable.Executable, result *ParseResult) error
func ExecutablesFromBatFile ¶
func ExecutablesFromBatFile(wsPath, filePath string) (*executable.Executable, error)
func ExecutablesFromDockerCompose ¶
func ExecutablesFromDockerCompose(wsPath, path string) (executable.ExecutableList, error)
ExecutablesFromDockerCompose parses a docker-compose.yml and returns list of Executables for the services
func ExecutablesFromImports ¶
func ExecutablesFromImports( wsName string, flowFile *executable.FlowFile, ) (executable.ExecutableList, error)
func ExecutablesFromMakefile ¶
func ExecutablesFromMakefile(wsPath, path string) (executable.ExecutableList, error)
ExecutablesFromMakefile parses a Makefile and returns a list of Executables for each makeTarget
func ExecutablesFromPackageJSON ¶
func ExecutablesFromPackageJSON(wsPath, path string) (executable.ExecutableList, error)
ExecutablesFromPackageJSON parses package.json scripts and returns a list of Executables for them
func ExecutablesFromPs1File ¶
func ExecutablesFromPs1File(wsPath, filePath string) (*executable.Executable, error)
func ExecutablesFromShFile ¶
func ExecutablesFromShFile(wsPath, filePath string) (*executable.Executable, error)
func InferVerb ¶
func InferVerb(name string) executable.Verb
InferVerb infers the most likely Executable verb from a script or makeTarget name.
func NormalizeName ¶
NormalizeName strips any character that is not a letter, number, dash, or underscore, and also removes the verb prefix from the name if present.
Types ¶
type ParseResult ¶
type ParseResult struct {
SimpleFields map[string]string
Params executable.ParameterList
Args executable.ArgumentList
}
func ExtractExecConfig ¶
func ExtractExecConfig(data, prefix string) (*ParseResult, error)
Click to show internal directories.
Click to hide internal directories.