vault

package
v2.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

const (
	DefaultVaultKeyEnv      = "FLOW_VAULT_KEY"
	DefaultVaultIdentityEnv = "FLOW_VAULT_IDENTITY"
)
const DemoVaultReservedName = "demo"

Variables

This section is empty.

Functions

func CacheDirectory

func CacheDirectory(subPath string) string

func ConfigFilePath

func ConfigFilePath(vaultName string) string

func RefToParts

func RefToParts(ref SecretRef) (vaultName, key string, err error)

func ValidateIdentifier

func ValidateIdentifier(reference string) error

func VaultFromName

func VaultFromName(name string) (*VaultConfig, Vault, error)

Types

type CreateResult

type CreateResult struct {
	Name         string `json:"name"`
	Type         string `json:"type"`
	GeneratedKey string `json:"generatedKey,omitempty"`
}

CreateResult contains metadata about a newly created vault.

func NewAES256Vault

func NewAES256Vault(name, storagePath, keyEnv, keyFile string) (*CreateResult, error)

func NewAgeVault

func NewAgeVault(name, storagePath, recipients, identityKey, identityFile string) (*CreateResult, error)

func NewExternalVault

func NewExternalVault(providerConfigFile string) (*CreateResult, error)

func NewKeyringVault

func NewKeyringVault(name string) (*CreateResult, error)

func NewUnencryptedVault

func NewUnencryptedVault(name, storagePath string) (*CreateResult, error)

type Secret

type Secret interface {
	vault.Secret
	types.Entity

	Ref() SecretRef
	AsPlaintext() Secret
	AsObfuscatedText() Secret
}

func NewSecret

func NewSecret(vaultName, key string, value vault.Secret) (Secret, error)

type SecretList

type SecretList []Secret

func NewSecretList

func NewSecretList(vaultName string, v Vault) (SecretList, error)

func (SecretList) AsObfuscatedText

func (l SecretList) AsObfuscatedText() SecretList

func (SecretList) AsPlaintext

func (l SecretList) AsPlaintext() SecretList

func (SecretList) FindByName

func (l SecretList) FindByName(name string) Secret

func (SecretList) Items

func (l SecretList) Items() []*types.EntityInfo

func (SecretList) JSON

func (l SecretList) JSON() (string, error)

func (SecretList) JSONWithMode

func (l SecretList) JSONWithMode(plaintext bool) (string, error)

JSONWithMode allows explicit control over plaintext vs obfuscated serialization

func (SecretList) Plural

func (l SecretList) Plural() string

func (SecretList) Singular

func (l SecretList) Singular() string

func (SecretList) YAML

func (l SecretList) YAML() (string, error)

func (SecretList) YAMLWithMode

func (l SecretList) YAMLWithMode(plaintext bool) (string, error)

YAMLWithMode allows explicit control over plaintext vs obfuscated serialization

type SecretRef

type SecretRef string

func (SecretRef) Key

func (r SecretRef) Key() string

func (SecretRef) Vault

func (r SecretRef) Vault() string

type SecretValue

type SecretValue = vault.SecretValue

func NewSecretValue

func NewSecretValue(value []byte) *SecretValue

type Vault

type Vault = vault.Provider

type VaultConfig

type VaultConfig = vault.Config

Jump to