Documentation
¶
Index ¶
- Constants
- func ExecWithCmd(cmd string) gomock.Matcher
- func ExecWithRef(ref executable.Ref) gomock.Matcher
- func FindSubExecs(rootExec *executable.Executable, flowFiles executable.FlowFileList) executable.ExecutableList
- func MaybeUpdateGolden(tb testing.TB, out []byte)
- func NormalizeTmpDirs(input string) string
- func RequireEqualSnapshot(tb testing.TB, out []byte)
- func ResetTestContext(ctx *Context, tb testing.TB)
- func UpdateGolden(tb testing.TB, out []byte)
- type CommandRunner
- type Context
- type ContextWithMocks
- type ExitRecorder
Constants ¶
const ( TestWorkspaceName = "test" TestWorkspaceDisplayName = "Test Workspace" )
Variables ¶
This section is empty.
Functions ¶
func ExecWithCmd ¶
func ExecWithRef ¶
func ExecWithRef(ref executable.Ref) gomock.Matcher
func FindSubExecs ¶
func FindSubExecs(rootExec *executable.Executable, flowFiles executable.FlowFileList) executable.ExecutableList
FindSubExecs returns a list of sub-executables for the given root executable.
func MaybeUpdateGolden ¶
func NormalizeTmpDirs ¶
NormalizeTmpDirs replaces all file paths under the system temp dir with /TMPDIR.
func RequireEqualSnapshot ¶
func ResetTestContext ¶
func UpdateGolden ¶
Types ¶
type CommandRunner ¶
type CommandRunner struct{}
func NewE2ECommandRunner ¶
func NewE2ECommandRunner() *CommandRunner
type Context ¶
func NewContext ¶
NewContext creates a new context for testing runners. It initializes the context with a real logger that writes it's output to a temporary file. It also creates a temporary testing directory for the test workspace, user configs, and caches. Test environment variables are set the config and cache directories override paths.
func (*Context) ExitCalls ¶
ExitCalls returns the fatal messages captured while the context was in failure-capture mode.
func (*Context) ExpectFailure ¶
func (c *Context) ExpectFailure()
ExpectFailure flips the test context into capture mode: subsequent fatal logger calls will be recorded on the context and cause the currently executing command to return an error instead of failing the test. Reset on every ResetTestContext call.
func (*Context) WorkspaceDir ¶
type ContextWithMocks ¶
type ContextWithMocks struct {
Ctx *context.Context
Logger *tuikitIOMocks.MockLogger
ExecutableCache *cacheMocks.MockExecutableCache
WorkspaceCache *cacheMocks.MockWorkspaceCache
RunnerMock *mocks.MockRunner
}
func NewContextWithMocks ¶
func NewContextWithMocks(ctx stdCtx.Context, tb testing.TB) *ContextWithMocks
NewContextWithMocks creates a new context for testing runners. It initializes the context with a mock logger and mock caches. The mock logger is set to expect debug calls.
type ExitRecorder ¶
type ExitRecorder struct {
// contains filtered or unexported fields
}
ExitRecorder routes logger fatal calls so they can be asserted on in tests rather than aborting the process or the test goroutine.